@@ -73,14 +73,14 @@ def syncify_async_function(async_func):
     except:
         loop = asyncio.new_event_loop()
         asyncio.set_event_loop(loop)
-
-    def sync_func(*args, **kwargs):
-        if not loop.is_running():
-            loop.run_until_complete(asyncio.sleep(0))
-
-        return loop.run_until_complete(async_func(*args, **kwargs))
-
-    return sync_func
+    asyncio.run(async_func)
+    # def sync_func(*args, **kwargs):
+    #     if not loop.is_running():
+    #         loop.run_until_complete(asyncio.sleep(0))
+    #
+    #     return loop.run_until_complete(async_func(*args, **kwargs))
+    #
+    # return sync_func
 
 
 class GSPeerConnectionBroadcasterPiSocketv2:
@@ -240,7 +240,7 @@ class GSPeerConnectionBroadcasterPiSocketv2:
                     async def setremotedescription():
                         await self.peerConnections[id].setRemoteDescription(answer)
 
-                    asyncio.run(setremotedescription())
+                    syncify_async_function(setremotedescription())
 
         @self.sio.event
         def disconnectBroadcaster(id, desc):
